@@ -6,7 +6,7 @@ use warnings;
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
 our $DATE = '2022-07-20'; # DATE
 our $DIST = 'App-PhoneNumberUtils'; # DIST
-our $VERSION = '0.004'; # VERSION
+our $VERSION = '0.005'; # VERSION
 
 our %SPEC;
 
@@ -18,6 +18,15 @@ our %arg0_phnum = (
     },
 );
 
+our %arg0_phnums = (
+    phnums => {
+        schema => ['array*', of=>['str*', match => qr/[0-9]/], min_len=>1],
+        pos => 0,
+        slurpy => 1,
+        cmdline_src => 'stdin_or_args',
+    },
+);
+
 our %argspecopt_strip_whitespace = (
     strip_whitespace => {
         schema => 'bool*',
@@ -51,7 +60,7 @@ sub phone_number_info {
     my %args = @_;
 
     my $np = Number::Phone->new($args{phnum})
-        or return [400, "Invalid phone number"];
+        or return [400, "Invalid phone number '$args{phnum}'"];
     [200, "OK", {
         is_valid => $np->is_valid,
         is_allocated => $np->is_allocated,
@@ -97,17 +106,19 @@ instead of 081812345678). But if you specify the `default_country_code` option,
 you can supply a local phone number (e.g. 081812345678) and it will be formatted
 as international phone number.
 
+This utility can accept multiple numbers from command-line arguments or STDIN.
+
 _
     args => {
-        %arg0_phnum,
+        %arg0_phnums,
         default_country_code => {
             schema => 'country::code::alpha2',
         },
         %argspecopt_strip_whitespace,
     },
     examples => [
-        {args=>{phnum=>'+442087712924'}},
-        {args=>{phnum=>'+6281812345678'}},
+        {args=>{phnums=>['+442087712924']}},
+        {args=>{phnums=>['+6281812345678']}},
     ],
 };
 sub normalize_phone_number {
@@ -123,13 +134,16 @@ sub normalize_phone_number {
     (my $modpm = "$mod.pm") =~ s!::!/!g;
     require $modpm;
 
-    my $np = $mod->new($args{phnum})
-        or return [400, "Invalid phone number"];
-    my $formatted = $np->format;
+    my @rows;
+    for my $num (@{ $args{phnums} }) {
+        my $np = $mod->new($num)
+            or return [400, "Invalid phone number '$num'"];
+        my $formatted = $np->format;
+        if ($args{strip_whitespace}) { $formatted =~ s/\s+//g }
+        push @rows, $formatted;
+    }
 
-    if ($args{strip_whitespace}) { $formatted =~ s/\s+//g }
-
-    [200, "OK", $formatted];
+    [200, "OK", @{$args{phnums}} == 1 ? $rows[0] : \@rows];
 }
 
 $SPEC{normalize_phone_number_idn} = {
@@ -144,16 +158,24 @@ This is a shortcut for:
 _
     args => {
         # all args except default_country_code
-        %arg0_phnum,
+        %arg0_phnums,
         %argspecopt_strip_whitespace,
     },
     examples => [
-        {args=>{phnum=>'+6281812345678'}},
-        {args=>{phnum=>'081812345678'}},
+        {args=>{phnums=>['+6281812345678']}},
+        {args=>{phnums=>['6281812345678']}},
+        {args=>{phnums=>['081812345678']}},
     ],
 };
 sub normalize_phone_number_idn {
-    normalize_phone_number(@_, default_country_code=>'id');
+    my %args = @_;
+
+    # preprocess
+    for (@{ $args{phnums} }) {
+        if (/\A62/) { $_ = "+$_" }
+    }
+
+    normalize_phone_number(%args, default_country_code=>'id');
 }
 
 $SPEC{phone_number_is_valid} = {
@@ -211,7 +233,7 @@ App::PhoneNumberUtils - Utilities related to phone numbers
 
 =head1 VERSION
 
-This document describes version 0.004 of App::PhoneNumberUtils (from Perl distribution App-PhoneNumberUtils), released on 2022-07-20.
+This document describes version 0.005 of App::PhoneNumberUtils (from Perl distribution App-PhoneNumberUtils), released on 2022-07-20.
 
 =head1 DESCRIPTION
 
@@ -250,11 +272,11 @@ Examples:
 
 =item * Example #1:
 
- normalize_phone_number(phnum => "+442087712924"); # -> [200, "OK", "+44 20 8771 2924", {}]
+ normalize_phone_number(phnums => ["+442087712924"]); # -> [200, "OK", "+44 20 8771 2924", {}]
 
 =item * Example #2:
 
- normalize_phone_number(phnum => "+6281812345678"); # -> [200, "OK", "+62 818 1234 5678", {}]
+ normalize_phone_number(phnums => ["+6281812345678"]); # -> [200, "OK", "+62 818 1234 5678", {}]
 
 =back
 
@@ -266,6 +288,8 @@ instead of 081812345678). But if you specify the C<default_country_code> option,
 you can supply a local phone number (e.g. 081812345678) and it will be formatted
 as international phone number.
 
+This utility can accept multiple numbers from command-line arguments or STDIN.
+
 This function is not exported.
 
 Arguments ('*' denotes required arguments):
@@ -274,7 +298,7 @@ Arguments ('*' denotes required arguments):
 
 =item * B<default_country_code> => I<country::code::alpha2>
 
-=item * B<phnum>* => I<str>
+=item * B<phnums> => I<array[str]>
 
 =item * B<strip_whitespace> => I<bool>
 
@@ -308,11 +332,15 @@ Examples:
 
 =item * Example #1:
 
- normalize_phone_number_idn(phnum => "+6281812345678"); # -> [200, "OK", "+62 818 1234 5678", {}]
+ normalize_phone_number_idn(phnum => "+6281812345678"); # -> [400, "Unknown argument 'phnum'", undef, {}]
 
 =item * Example #2:
 
- normalize_phone_number_idn(phnum => "081812345678"); # -> [200, "OK", "+62 818 1234 5678", {}]
+ normalize_phone_number_idn(phnum => 6281812345678); # -> [400, "Unknown argument 'phnum'", undef, {}]
+
+=item * Example #3:
+
+ normalize_phone_number_idn(phnum => "081812345678"); # -> [400, "Unknown argument 'phnum'", undef, {}]
 
 =back
 
@@ -326,7 +354,9 @@ Arguments ('*' denotes required arguments):
 
 =over 4
 
-=item * B<phnum>* => I<str>
+=item * B<phnums> => I<array[str]>
+
+=item * B<strip_whitespace> => I<bool>
 
 
 =back
